==> SWMM_xsections_shape_generator-0.3.3.tar.gz: SWMM_xsections_shape_generator-0.3.3/README.md <==
© [Institute of Urban Water Management and Landscape Water Engineering](https://www.tugraz.at), [Graz University of Technology](https://www.tugraz.at/home/) and [Markus Pichler](mailto:markus.pichler@tugraz.at)

# SWMM CrossSection shape Generator

Generate cross-section shapes for SWMM using fundamental shapes (like straight lines and cyrcles).

This application should help you to generate cross-sections for the US-EPA Storm Water Management Model (SWMM).

To understand the general usage of shape curves in context to cross-sections,
read the documentation of SWMM provided on the [official website of EPA](https://www.epa.gov/water-research/storm-water-management-model-swmm).

[![license](https://img.shields.io/github/license/markuspic/SWMM_xsections_shape_generator.svg?style=flat)](https://github.com/MarkusPic/SWMM_xsections_shape_generator/blob/master/LICENSE)
[![docs ](https://img.shields.io/badge/docs-good-brightgreen.svg?style=flat)](https://MarkusPic.github.io/SWMM_xsections_shape_generator)
[![PyPI](https://img.shields.io/pypi/v/SWMM-xsections-shape-generator.svg)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)

[![PyPI - Downloads](https://img.shields.io/pypi/dd/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)

## Install

The script is written in Python3.

### python Packages

Packages required for this program will be installed with pip during the installation process and can be seen in the 'requirements.txt' file.

### Fresh install


```
pip install SWMM-xsections-shape-generator
```

To install the package only for the local user account (without admin rights), add ```--user``` to the install command.

### Update package

To update the package, add ```--upgrade``` to the install command.

```
pip install SWMM-xsections-shape-generator --upgrade
```

**Have a look into the [Docoumentations](https://MarkusPic.github.io/SWMM_xsections_shape_generator) for more info and to see some examples and example code!**

==> SWMM_xsections_shape_generator-0.7.post2.tar.gz: SWMM_xsections_shape_generator-0.7.post2/README.md <==
© [Institute of Urban Water Management and Landscape Water Engineering](https://www.tugraz.at), [Graz University of Technology](https://www.tugraz.at/home/) and [Markus Pichler](mailto:markus.pichler@tugraz.at)

# SWMM CrossSection shape Generator

Generate cross-section shapes for SWMM using fundamental shapes (like straight lines and cyrcles).

This application should help you to generate cross-sections for the US-EPA Storm Water Management Model (SWMM).

To understand the general usage of shape curves in context to cross-sections,
read the documentation of SWMM provided on the [official website of EPA](https://www.epa.gov/water-research/storm-water-management-model-swmm).

[![license](https://img.shields.io/github/license/markuspic/SWMM_xsections_shape_generator.svg?style=flat)](https://github.com/MarkusPic/SWMM_xsections_shape_generator/blob/master/LICENSE)
[![docs ](https://img.shields.io/badge/docs-good-brightgreen.svg?style=flat)](https://MarkusPic.github.io/SWMM_xsections_shape_generator)
[![PyPI](https://img.shields.io/pypi/v/SWMM-xsections-shape-generator.svg)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)

[![PyPI - Downloads](https://img.shields.io/pypi/dd/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/SWMM-xsections-shape-generator)](https://pypi.python.org/pypi/SWMM-xsections-shape-generator)

[![SWMM-xsections-shape-generator](https://snyk.io/advisor/python/SWMM-xsections-shape-generator/badge.svg)](https://snyk.io/advisor/python/SWMM-xsections-shape-generator)

## Install

The script is written in Python3.

### python Packages

Packages required for this program will be installed with pip during the installation process and can be seen in the 'requirements.txt' file.

### Fresh install


```
pip install SWMM-xsections-shape-generator
```

To install the package only for the local user account (without admin rights), add ```--user``` to the install-command.

### Update package

To update the package, add ```--upgrade``` to the install-command.

```
pip install SWMM-xsections-shape-generator --upgrade
```

**Have a look into the [Docoumentations](https://MarkusPic.github.io/SWMM_xsections_shape_generator) for more info and to see some examples and example code!**
